==> svorm-0.1.6.tgz: package/Classes/Fields/MultipleField.js <==
import Field from './Field';
import Validations from '../Helpers/Validations';
/**
 * MutipleField class.
 *
 * @since 1.0.0
 */
export default class MultipleField extends Field {
    /**
     * Initializing field.
     *
     * @param fieldData  Field data.
     * @param formValues Form values.
     *
     * @since 1.0.0
     */
    constructor(fieldData, formValues = []) {
        super(fieldData, formValues);
        if (formValues === undefined || formValues[this.id] === undefined) {
            this.formValues[this.id] = [];
        }
    }
    /**
     * Get values of the mutliple field.
     *
     * @returns All values of the field.
     *
     * @since 1.0.0
     */
    getValues() {
        return this.formValues[this.id];
    }
    /**
    * Doing form things and get value of the field.
    *
    * @returns Value of the field.
    *
    * @since 1.0.0
    */
    getValue(index) {
        return this.formValues[this.id][index];
    }
    /**
     * Doing form things and g set value of the field.
     *
     * @param value Value to set.
     *
     * @since 1.0.0
     */
    setValue(value, index) {
        this.valueChanged = true;
        value = this.replace(value); // Auto replacements e.g. for points replace with comma.
        this.formValues[this.id][index] = value;
        return value;
    }
    /**
     * Add new value to the field.
     *
     * @param value New value.
     *
     * @since 1.0.0
     */
    addValue(value = '') {
        this.formValues[this.id].push(value);
    }
    /**
     * Remove value from the field.
     *
     * @param index Index of the value to remove.
     *
     * @since 1.0.0
     */
    removeValue(index) {
        this.formValues[this.id].splice(index, 1);
    }
    /**
     * Validate field values and set errors.
     *
     * @returns True if field is valid.
     *
     * @since 1.0.0
     */
    validate() {
        let validations;
        let errors = [];
        this.getValues().forEach((value) => {
            validations = new Validations(this.validations);
            validations.validate(value);
            if (validations.getErrors().length > 0) {
                errors.concat(validations.getErrors());
            }
        });
        this.errors = errors;
        return this.errors.length === 0;
    }
}

==> svorm-0.9.0.tgz: package/Classes/Fields/MultipleField.js <==
import Field from './Field';
import Validations from '../Helpers/Validations';
/**
 * MutipleField class.
 *
 * @since 1.0.0
 */
export default class MultipleField extends Field {
    /**
     * Initializing field.
     *
     * @param fieldData  Field data.
     * @param formValues Form values.
     *
     * @since 1.0.0
     */
    constructor(fieldData, formValues = {}) {
        super(fieldData, formValues);
        if (formValues === undefined || formValues[this.id] === undefined) {
            this.formValues[this.id] = [];
        }
        if (this.valueDefault !== undefined && this.getValues() === undefined) {
            this.formValues[this.id] = this.valueDefault;
        }
    }
    /**
     * Get values of the mutliple field.
     *
     * @returns All values of the field.
     *
     * @since 1.0.0
     */
    getValues() {
        return this.formValues[this.id];
    }
    /**
    * Doing form things and get value of the field.
    *
    * @returns Value of the field.
    *
    * @since 1.0.0
    */
    getValue(index) {
        return this.formValues[this.id][index];
    }
    /**
     * Doing form things and g set value of the field.
     *
     * @param value Value to set.
     *
     * @since 1.0.0
     */
    setValue(value, index) {
        value = this.replace(value); // Auto replacements e.g. for points replace with comma.
        this.formValues[this.id][index] = value;
        return value;
    }
    /**
     * Set values of the field.
     *
     * @param values All values of the field.
     *
     * @since 1.0.0
     */
    setValues(values) {
        this.formValues[this.id] = values;
    }
    /**
     * Add new value to the field.
     *
     * @param value New value.
     *
     * @since 1.0.0
     */
    addValue(value = '') {
        this.formValues[this.id].push(value);
    }
    /**
     * Remove value from the field.
     *
     * @param index Index of the value to remove.
     *
     * @since 1.0.0
     */
    removeValue(index) {
        this.formValues[this.id].splice(index, 1);
    }
    /**
     * Validate field values and set errors.
     *
     * @returns True if field is valid.
     *
     * @since 1.0.0
     */
    validate() {
        let validations;
        let errors = [];
        this.getValues().forEach((value) => {
            validations = new Validations(this.validations);
            validations.validate(value);
            if (validations.getErrors().length > 0) {
                errors.concat(validations.getErrors());
            }
        });
        this.isValidated = true;
        this.errors = errors;
        return this.errors.length === 0;
    }
}
